@@ -9,4 +9,5 @@ def metadata(request):
             'version': getattr(settings, 'VERSION', 'N/A'),
             'shop_name': settings.OSCAR_SHOP_NAME,
             'shop_tagline': settings.OSCAR_SHOP_TAGLINE,
-            'google_analytics_id': getattr(settings, 'GOOGLE_ANALYTICS_ID', None)}
\ No newline at end of file
+            'google_analytics_id': getattr(settings,
+                                           'GOOGLE_ANALYTICS_ID', None)}
