@@ -10,7 +10,8 @@ def get_parameters(parser, token):
 
     args = token.split_contents()
     if len(args) < 2:
-        raise template.TemplateSyntaxError, "get_parameters tag takes at least 1 argument"
+        raise template.TemplateSyntaxError(
+            "get_parameters tag takes at least 1 argument")
     return GetParametersNode(args[1].strip())
 
 
@@ -35,4 +36,4 @@ class GetParametersNode(template.Node):
 
         return get_params
 
-get_parameters = register.tag(get_parameters)
\ No newline at end of file
+get_parameters = register.tag(get_parameters)
